Wazimap Mapit
=============

Support for using Mapit maps in `Wazimap <http://wazimap.readthedocs.org/en/latest/>`_, generally from `mapit.code4sa.org <http://mapit.code4sa.org>`_.

Releasing a New Version
-----------------------

1. Update VERSION appropriately
2. Update the CHANGES.rst
3. Commit and push to github
4. Release to PyPI::

    python setup.py sdist bdist_wheel upload

License
=======

Licensed under the MIT License.
